@@ -13,11 +13,12 @@ package Printer::ESCPOS;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.024'; # VERSION
+our $VERSION = '0.025'; # VERSION
 
 # Dependencies
 use 5.010;
 use Moo;
+use Class::Load;
 use Carp;
 use Type::Tiny;
 use aliased 'Printer::ESCPOS::Roles::Profile' => 'ESCPOSProfile';
@@ -158,10 +159,7 @@ Printer::ESCPOS - Interface for all thermal, dot-matrix and other receipt printe
 =begin html
 
 <p>
-<img src="https://img.shields.io/badge/perl-5.10+-brightgreen.svg" alt="Requires Perl 5.10+" />
 <a href="https://travis-ci.org/shantanubhadoria/perl-Printer-ESCPOS"><img src="https://api.travis-ci.org/shantanubhadoria/perl-Printer-ESCPOS.svg?branch=build/master" alt="Travis status" /></a>
-<a href="http://matrix.cpantesters.org/?dist=Printer-ESCPOS%200.024"><img src="https://badgedepot.code301.com/badge/cpantesters/Printer-ESCPOS/0.024" alt="CPAN Testers result" /></a>
-<a href="http://cpants.cpanauthors.org/dist/Printer-ESCPOS-0.024"><img src="https://badgedepot.code301.com/badge/kwalitee/Printer-ESCPOS/0.024" alt="Distribution kwalitee" /></a>
 <a href="https://gratipay.com/shantanubhadoria"><img src="https://img.shields.io/gratipay/shantanubhadoria.svg" alt="Gratipay" /></a>
 </p>
 
@@ -169,7 +167,7 @@ Printer::ESCPOS - Interface for all thermal, dot-matrix and other receipt printe
 
 =head1 VERSION
 
-version 0.024
+version 0.025
 
 =head1 SYNOPSIS
 
